// this function verifies disk space in kilobytes
function verifyDiskSpace(dirPath, spaceRequired)
{
    var spaceAvailable;
    spaceAvailable = fileGetDiskSpaceAvailable(dirPath);
    spaceAvailable = parseInt(spaceAvailable / 1024);

    if (spaceAvailable < spaceRequired)
    {
        logComment("Insufficient disk space: " + dirPath);
        logComment("  required : " + spaceRequired + " K");
        logComment("  available: " + spaceAvailable + " K");
        return (false);
    }
    return (true);
}

// OS type detection
// which platform?
function getPlatform()
{
    var platformStr;
    var platformNode;

    if ('platform' in Install)
    {
        platformStr = new String(Install.platform);
        logComment("platformStr: " + platformStr);

        if (!platformStr.search(/^Macintosh/))
            platformNode = 'mac';
        else if (!platformStr.search(/^Win/))
            platformNode = 'win';
        else
            platformNode = 'unix';
    }
    else
    {
        var fOSMac = getFolder("Mac System");
        var fOSWin = getFolder("Win System");

        logComment("fOSMac: " + fOSMac);
        logComment("fOSWin: " + fOSWin);

        if (fOSMac != null)
            platformNode = 'mac';
        else if (fOSWin != null)
            platformNode = 'win';
        else
            platformNode = 'unix';
    }

    return platformNode;
}

// main
var srDest;
var err;
var fProgram;

platformNode = getPlatform();
logComment("initInstall: platformNode=" + platformNode);
// end - OS type detection

// ----LOCALIZATION NOTE: translate only these ------
var prettyName = "Japanese (Japan) Language Pack";
var langcode = "ja";
var chromeNode = langcode + "-JP";
// --- END CHANGABLE STUFF ---
var regName = "locales/mozilla/" + chromeNode;
var chromeName = chromeNode + ".jar";
var platformName = langcode + "-" + platformNode + ".jar";
var localeName = "locale/" + chromeNode + "/";

srDest = 641;
err = initInstall(prettyName, regName, "0.9.x");
logComment("initInstall: " + err);

fProgram = getFolder("Program");
logComment("fProgram: " + fProgram);

if (verifyDiskSpace(fProgram, srDest))
{
    var chromeType = LOCALE | DELAYED_CHROME;
    err = addDirectory("", "bin", fProgram, "");
    logComment("addDirectory() returned: " + err);

    // if (err != SUCCESS)
    // {
    //     logComment("addDirectory() to " + fProgram + "failed!");
    //     // couldn't install globally, try installing to the profile

    //     resetError();
    //     chromeType |= PROFILE_CHROME;
    //     fProgram = getFolder("Profile");
    //     logComment("try installing to the user profile:" + fProgram);
    //     err = addDirectory("", "bin/chrome", fProgram, "chrome");
    // }

    setPackageFolder(fProgram);

    // check return value
    if (err == SUCCESS)
    {
        // register chrome
        var cf = getFolder(fProgram, "chrome/" + chromeName);
        var pf = getFolder(fProgram, "chrome/" + platformName);

        registerChrome(chromeType, cf, localeName + "global/");
        registerChrome(chromeType, cf, localeName + "communicator/");

        registerChrome(chromeType, cf, localeName + "messenger/");
        registerChrome(chromeType, cf, localeName + "editor/");
        registerChrome(chromeType, cf, localeName + "navigator/");
        registerChrome(chromeType, cf, localeName + "necko/");
        registerChrome(chromeType, cf, localeName + "cookie/");
        registerChrome(chromeType, cf, localeName + "wallet/");
        registerChrome(chromeType, cf, localeName + "pipnss/");
        registerChrome(chromeType, cf, localeName + "pippki/");
        registerChrome(chromeType, cf, localeName + "content-packs/");
        registerChrome(chromeType, cf, localeName + "help/");
        registerChrome(chromeType, cf, localeName + "mozldap/");
        registerChrome(chromeType, cf, localeName + "forms/");
        registerChrome(chromeType, cf, localeName + "messenger-smime/");
        registerChrome(chromeType, cf, localeName + "chatzilla/");
        registerChrome(chromeType, cf, localeName + "venkman/");
        registerChrome(chromeType, cf, localeName + "inspector/");

        registerChrome(chromeType, pf, localeName + "global-platform/");
        registerChrome(chromeType, pf, localeName + "communicator-platform/");
        registerChrome(chromeType, pf, localeName + "navigator-platform/");

        if (platformNode == "win")
            registerChrome(chromeType, pf, localeName + "messenger-mapi/");

        err = performInstall();
        logComment("performInstall() returned: " + err);

        if (err == SUCCESS || err == 999)
        {
            alert("Installation finished. After a browser restart, you should be able to select to use this locale.");
        }
        else
        {
            alert("Installation failed. Error code was " + err);
        }

    }
    else
    {
        cancelInstall(err);
        logComment("cancelInstall due to error: " + err);

        if (err == -202)
        {
            alert("Installation canceled with error " + err +
                  ". It seems you have no write permission to the Mozilla 'chrome' directory. Please install as root / system administrator.");
        }
        else
        {
            alert("Installation canceled. Error code was " + err);
        }
    }
}
else
    cancelInstall(INSUFFICIENT_DISK_SPACE);

// end main
